# Licensed under a 3-clause BSD style license - see LICENSE.rst


def get_package_data():
    files = ["datasets.yaml"]
    return {"gammapy.datasets": files}
